ArticleEmbedPayloadBlock class final

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)

Constructors

ArticleEmbedPayloadBlock({required String id, String type = "embed", String name = "embed", ArticleEmbedBlock? data})
const
ArticleEmbedPayloadBlock.fromJson(Map<String, dynamic> json)
factory

Properties

data → ArticleEmbedBlock?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited