BookmarkSortType enum

Inheritance
Available extensions

Values

newToOldAddTime → const BookmarkSortType
const BookmarkSortType(1, "NewToOldAddTime")
oldToNewAddTime → const BookmarkSortType
const BookmarkSortType(2, "OldToNewAddTime")
newToOldYear → const BookmarkSortType
const BookmarkSortType(3, "NewToOldYear")
oldToNewYear → const BookmarkSortType
const BookmarkSortType(4, "OldToNewYear")
alpabetInAToZ → const BookmarkSortType
const BookmarkSortType(5, "AlpabetInAToZ")
alpabetInZToA → const BookmarkSortType
const BookmarkSortType(6, "AlpabetInZToA")

Properties

codeName → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BookmarkSortType>
A constant List of the values in this enum, in order of their declaration.