ChannelResponse class final
- Annotations
-
- @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)
Constructors
- ChannelResponse({required int code, Channel? channel, int? suggestionCount})
-
const
-
ChannelResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- channel → Channel?
-
final
- code → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestionCount → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited