CollectionCreateEditRequest class final

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)

Constructors

CollectionCreateEditRequest({required String title, required String description, required bool isPrivate, required List<int> releases})
const
CollectionCreateEditRequest.fromJson(Map<String, dynamic> json)
factory

Properties

description → String
final
hashCode → int
The hash code for this object.
no setterinherited
isPrivate → bool
final
releases → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited