DeleteNotificationType enum

Inheritance
Available extensions

Values

articleComment → const DeleteNotificationType
const DeleteNotificationType("article/comment", "ArticleComment")
collectionComment → const DeleteNotificationType
const DeleteNotificationType("collectionComment", "CollectionComment")
episode → const DeleteNotificationType
const DeleteNotificationType("episode", "Episode")
friend → const DeleteNotificationType
const DeleteNotificationType("friend", "Friend")
myArticleComment → const DeleteNotificationType
const DeleteNotificationType("my/article/comment", "MyArticleComment")
myCollectionComment → const DeleteNotificationType
const DeleteNotificationType("my/collection/comment", "MyCollectionComment")
relatedRelease → const DeleteNotificationType
const DeleteNotificationType("related/release", "RelatedRelease")
releaseComment → const DeleteNotificationType
const DeleteNotificationType("releaseComment", "ReleaseComment")

Properties

codeName → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DeleteNotificationType>
A constant List of the values in this enum, in order of their declaration.