FriendStatusResponse class final

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)

Constructors

FriendStatusResponse({required int code, FriendStatus? friendStatus})
const
FriendStatusResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code → int
final
friendStatus → FriendStatus?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited