HttpRequest class final

Constructors

HttpRequest({required HttpMethod method, required String path, HttpParameters? query, HttpBody? body, HttpAuth? auth, String? customBaseUrl, List<int>? successCodes, Map<int, String>? resultEnum, Map<String, String> headers = const {}, RequestOptions options = const RequestOptions()})
const

Properties

auth → HttpAuth?
final
body → HttpBody?
final
customBaseUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
method → HttpMethod
final
options → RequestOptions
final
path → String
final
query → HttpParameters?
final
resultEnum → Map<int, String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successCodes → List<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited