ProfileEpisodeNotification class final

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)

Constructors

ProfileEpisodeNotification({ProfileNotificationType? type, required int id, int? timestamp, bool? isNew, bool? isPushed, EpisodeCompact? episode})
const
ProfileEpisodeNotification.fromJson(Map<String, dynamic> json)
factory

Properties

episode → EpisodeCompact?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
isNew → bool?
final
isPushed → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int?
final
type → ProfileNotificationType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited