ProfileRole class final

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)

Constructors

ProfileRole({int? badgeId, String? badgeName, int? badgeType, String? badgeUrl, int? banExpires, String? banReason, required int id, bool? isBanned, bool? isSponsor, bool? isVerified, int? privilegeLevel, String? login, String? avatar, bool? isOnline, List<Role>? roles})
const
ProfileRole.fromJson(Map<String, dynamic> json)
factory

Properties

avatar → String?
final
badgeId → int?
final
badgeName → String?
final
badgeType → int?
final
badgeUrl → String?
final
banExpires → int?
final
banReason → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
isBanned → bool?
final
isOnline → bool?
final
isSponsor → bool?
final
isVerified → bool?
final
login → String?
final
privilegeLevel → int?
final
roles → List<Role>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited