ReportRequest<T> class final

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true, genericArgumentFactories: true)

Constructors

ReportRequest({T? entityId, required String message, required int reason})
const
ReportRequest.fromJson(Map<String, dynamic> json, T fromJsonT(Object?))
factory

Properties

entityId → T?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
reason → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object? toJsonT(T)) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited