AnixartHttpClient class
Constructors
- AnixartHttpClient({required String baseUrl, required String userAgent, required bool throwOnAnixartError, String? token})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
getBaseUrl(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request<
T> (HttpRequest request, {ResponseDecoder< T> ? decoder}) → Future<HttpResponse< T> > -
setBaseUrl(
String baseUrl) → void -
setToken(
String? token) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited