Article class final
- Annotations
-
- @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)
Constructors
-
Article({int? jsonId, required int id, Channel? channel, ProfileSlim? author, EntityReference<
Article> ? repostArticle, ArticlePayload? payload, int? creationDate, int? lastUpdateDate, int? commentCount, int? repostCount, int? voteCount, int? vote, bool? containsRepostArticle, bool? isSigned, bool? isPinned, bool? isMuted, bool? isDeleted, bool? hasDeleteEnforcement, PopularComment? popularComment}) -
const
-
Article.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
final
- channel → Channel?
-
final
- commentCount → int?
-
final
- containsRepostArticle → bool?
-
final
- creationDate → int?
-
final
- hasDeleteEnforcement → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- isDeleted → bool?
-
final
- isMuted → bool?
-
final
- isPinned → bool?
-
final
- isSigned → bool?
-
final
- jsonId → int?
-
final
- lastUpdateDate → int?
-
final
- payload → ArticlePayload?
-
final
- popularComment → PopularComment?
-
final
-
repostArticle
→ EntityReference<
Article> ? -
final
- repostCount → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vote → int?
-
final
- voteCount → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited