ArticleCommentCompact class final
- Annotations
-
- @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)
Constructors
- ArticleCommentCompact({required int id, ProfileSlim? profile, String? message, bool? isSpoiler, ArticleCompact? article, int? embeddableId, String? embeddableTitle, String? embeddableDescription})
-
const
-
ArticleCommentCompact.fromJson(Map<
String, dynamic> json) -
factory
Properties
- article → ArticleCompact?
-
final
- embeddableDescription → String?
-
final
- embeddableId → int?
-
final
- embeddableTitle → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- isSpoiler → bool?
-
final
- message → String?
-
final
- profile → ProfileSlim?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited