OAuthSignInResponse class final
- Annotations
-
- @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true)
Constructors
-
OAuthSignInResponse({required int code, Profile? profile, ProfileToken? profileToken, int? codeTimestampExpires, List<
String> ? suggestedLogins, String? hash}) -
const
-
OAuthSignInResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- code → int
-
final
- codeTimestampExpires → int?
-
final
- hash → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile → Profile?
-
final
- profileToken → ProfileToken?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
suggestedLogins
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited